@@ -1,5 +1,5 @@
 package Task::MetaSyntactic;
-$Task::MetaSyntactic::VERSION = '1.041';
+$Task::MetaSyntactic::VERSION = '1.042';
 use strict;
 use warnings;
 
@@ -194,6 +194,64 @@ L<Data::Fake> generates randomized data using declarative syntax.
 This module exports factory functions that collect data from the installed
 L<Acme::MetaSyntactic> theme.
 
+=item L<WordList::MetaSyntactic> (PERLANCAR)
+
+First released on 2016-06-06.
+
+This module is a base class for C<WordList::MetaSyntactic::*> modules,
+wordlist modules that get their wordlist from corresponding
+C<Acme::MetaSyntactic::*> modules.
+
+=item L<WordList::MetaSyntactic::dangdut> (PERLANCAR)
+
+First released on 2016-06-06.
+
+This is the first (and for now only) wordlist module based
+on L<WordList::MetaSyntactic>. It takes its word list from
+L<Acme::MetaSyntactic::dangdut>.
+
+=item L<Acme::MetaSyntactic::WordList> (PERLANCAR)
+
+First released on 2016-06-08.
+
+Just like L<Acme::MetaSyntactic::cpanauthors> and
+L<Acme::CPANAuthors::MetaSyntactic> are two sides of the
+same coin, L<Acme::MetaSyntactic::WordList> is the dual of
+L<WordList::MetaSyntactic>: a base class for C<Acme::MetaSyntactic::*>
+modules that get their meta names from a corresponding C<WordList::*>
+module. See L<Acme::MetaSyntactic::countries> for an example.
+
+=item L<App::ShellCompleter::meta> (PERLANCAR)
+
+First released on 2016-11-04.
+
+Shell completer for L<meta>, using L<Shell::Completer>.
+
+=item L<Dist::Zilla::Plugin::Acme::MetaSyntactic> (PERLANCAR)
+
+First released on 2017-02-04.
+
+A L<Dist::Zilla> plugin that automates some of the steps of building an
+Acme-MetaSyntactic-* theme distribution.
+
+=item L<App::metastasize> (PERLANCAR)
+
+First released on 2017-02-11.
+
+This is an application based on L<Acme::PPIx::MetaSyntactic>.
+
+=item L<Complete::Acme::MetaSyntactic> (PERLANCAR)
+
+First released on 2017-02-15.
+
+Completion routines for L<Acme::MetaSyntactic>.
+
+=item L<App::metasyn> (PERLANCAR)
+
+First released on 2017-02-17.
+
+An alternative to the L<meta> front-end to L<Acme::MetaSyntactic>.
+
 =back
 
 =head1 AUTHOR
@@ -202,7 +260,7 @@ Philippe Bruhat (BooK), <book@cpan.org>.
 
 =head1 COPYRIGHT
 
-Copyright 2005-2016 Philippe Bruhat (BooK), All Rights Reserved.
+Copyright 2005-2017 Philippe Bruhat (BooK), All Rights Reserved.
 
 =head1 LICENSE
 
